@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Failsafe;
 
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 sub register {
     my ($self, %args) = @_;
@@ -31,7 +31,10 @@ YAML::PP::Schema::Failsafe - YAML 1.2 Failsafe Schema
 With this schema, everything will be treated as a string. There are no booleans,
 integers, floats or undefined values.
 
-L<https://yaml.org/spec/1.2/spec.html#id2802346>
+Here you can see all Schemas and examples implemented by YAML::PP:
+L<https://perlpunk.github.io/YAML-PP-p5/schemas.html>
+
+Official Schema: L<https://yaml.org/spec/1.2/spec.html#id2802346>
 
 =head1 METHODS
 
